/*
 * Virtual Machine IPC
 *
 * Copyright (c) 2014 Wind River Systems, Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef __VMIPC_H
#define __VMIPC_H

#define MAX_NUM_VM		1		/* We only support 1 VM currently */
#define IPC_TOTAL_MEM_SIZE	1		/* Size of shared memory block in MB units */
#define IPC_BUF_SIZE		4096


/* length in MB */
void *ivshm_open(char *path, int length, int mmap_offset, int ptr_offset);
void ivshm_close(void *memptr, int length);

/* size in bytes */
void ivshm_clean (void *memptr, int size);

void ivshm_show (void *ptr, int length);

typedef struct {
	char *buf_local;
	char *buf_remote;
} ivshm_addr;

typedef struct 
{
    int size;
    int msg_offset;
    int wr_ptr;
    int rd_ptr;
    unsigned char data[1];
}
ipc_t;

typedef struct
{
    int size;
    int type;
    unsigned char data[1];
}
ipc_msg_t;

void ipc_init (void *local, int size);
void ipc_show (void *p);
int ipc_read (void *local, void *remote, ipc_msg_t *msg);
int ipc_write (void *local, void *remote, ipc_msg_t *msg);


typedef struct
{
    int size;
    int type;
    int reported_vm_state;
}
vmipc_msg_t;

/* Reserved list of vm_states */
#define MIGRATION_START			1000
#define MIGRATION_END			1001

#endif
